How to Jupyter
==============

The project that you have installed by using the `pip install cnn-methods` command is just the Python library, however, the project also includes Jupyter notebooks that demonstrate the usage of the library for various tasks. To access these notebooks, follow these steps:

.. code-block:: bash

    git clone https://github.com/rorro6787/CNN-YOLO-SAM-segmentation.git
    cd CNN-YOLO-SAM-segmentation
    
Once you have cloned the repository, you will have to install the extra dependencies that perhaps you don't have installed in your system. To do so, you can run the following command:

.. code-block:: bash

    pip install hatch
    hatch build && pip install $(find dist -name "*.tar.gz")

Finally, you just have to navigate to the different notebooks that are located in the `notebooks` directory and choose the Jupyter kernel to run them, or you can also run the following command to open the Jupyter lab:

.. code-block:: bash

    jupyter lab